==> google-cloud-sdk-284.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/ai_platform/versions/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""ai-platform versions list command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.ml_engine import versions_api
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.ml_engine import flags
from googlecloudsdk.command_lib.ml_engine import versions_util


def _AddListArgs(parser):
  flags.GetModelName(positional=False, required=True).AddToParser(parser)
  flags.GetRegionArg('model').AddToParser(parser)


class List(base.ListCommand):
  """List existing AI Platform versions."""

  @staticmethod
  def Args(parser):
    _AddListArgs(parser)
    parser.display_info.AddFormat(
        'table(name.basename(), deploymentUri, state)')

  def Run(self, args):
    return versions_util.List(versions_api.VersionsClient(),
                              model=args.model)

==> google-cloud-sdk-286.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/ai_platform/versions/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""ai-platform versions list command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.ml_engine import versions_api
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.ml_engine import endpoint_util
from googlecloudsdk.command_lib.ml_engine import flags
from googlecloudsdk.command_lib.ml_engine import versions_util


def _AddListArgs(parser):
  flags.GetModelName(positional=False, required=True).AddToParser(parser)
  flags.GetRegionArg('model').AddToParser(parser)


class List(base.ListCommand):
  """List existing AI Platform versions."""

  @staticmethod
  def Args(parser):
    _AddListArgs(parser)
    parser.display_info.AddFormat(
        'table(name.basename(), deploymentUri, state)')

  def Run(self, args):
    with endpoint_util.MlEndpointOverrides(region=args.region):
      client = versions_api.VersionsClient()
      return versions_util.List(client, model=args.model)
